# (akien) bear-engine is built in the bear SRPM (same for bear-factory)
# We build against the same version but drop the conflicting files (libs and translations)
# TODO: Work with upstream to make bear-engine a real library and prevent building it
# in each game based upon the engine (so far two, but there's a third one we might package)
%define bear_version 0.7.0

Name:           andy-super-great-park
Version:        1.0.13
Release:        %mkrel 5
Summary:        A 2D shooter on rails
Group:          Games/Arcade
License:        GPLv3+ and CC-BY-SA 3.0
Url:            http://www.stuff-o-matic.com/asgp/
# https://github.com/j-jorge/agsp
Source0:        %{name}-%{version}.tar.xz
# Should be synced with the bear SRPM
Source1:        bear-%{bear_version}.tar.xz
Patch0:         andy-super-great-park-1.0.13-mga-boost-mutex.patch

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  docbook-to-man
BuildRequires:  gettext
BuildRequires:  libclaw-devel
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_mixer)

Requires:       %{name}-data >= %{version}
Requires:       bear-engine = 1:%{bear_version}

%description
Andy's Super Great Park is an original game with an inventive and easy to
learn gameplay, where every action can be simply done with a mouse.
Challenge your reflexes and your dexterity in this adventure of 25 to 43
levels, punctuated by amazing boss fights.

Through 25 main levels, you will have to retrieve a minimum number of
balloons using your plunger gun while avoiding collisions with the obstacles
dropped on the path (explosive zeppelins, crates, TNT…). Try to get the best
scores and unlock up to 18 extra levels!

Grabbing balloons with a plunger gun, shooting birds with a cannon and
exploding everything else, all while riding a roller coaster: this is Andy's
Super Great Park!

%files -f super-great-park.lang
%doc asgp/README.md asgp/LICENSE
%{_gamesbindir}/%{name}
%{_libdir}/bear/librp.so
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/asgp.png
%{_mandir}/man6/%{name}.6*

#----------------------------------------------------------------------

%package        data
Summary:        Data files for Andy's Super Great Park
License:        CC-BY-SA-3.0
BuildArch:      noarch

%description    data
These are the data files for Andy's Super Great Park arcade game.

%files          data
%{_gamesdatadir}/%{name}/
%{_datadir}/bear-factory/super-great-park/

#----------------------------------------------------------------------

%prep
%setup -q -a1
%autopatch -p1
mv bear-%{bear_version} bear

%build
%cmake -DBEAR_ENGINE_INSTALL_LIBRARY_DIR=%{_lib}/bear \
       -DBEAR_EDITORS_ENABLED=OFF \
       -DRP_INSTALL_CUSTOM_LIBRARY_DIR=%{_lib}/bear \
       -DRP_INSTALL_DATA_DIR=share/games/%{name} \
       -DRP_INSTALL_EXECUTABLE_DIR=games \
       -DRP_BEAR_FACTORY_ENABLED=ON
%make

%install
%makeinstall_std -C build

%find_lang super-great-park

# Remove the content already provided in the bear-engine package
rm -rf %{buildroot}%{_datadir}/cmake \
       %{buildroot}%{_datadir}/locale/*/LC_MESSAGES/bear-engine.mo \
       %{buildroot}%{_datadir}/pixmaps \
       %{buildroot}%{_libdir}/bear/libbear*.so \
       %{buildroot}%{_mandir}/man6/running-bear.6


%changelog
* Sat Dec 26 2015 daviddavid <daviddavid> 1.0.13-5.mga6
+ Revision: 915150
- rebuild for new boost 1.60.0

* Fri Sep 25 2015 daviddavid <daviddavid> 1.0.13-4.mga6
+ Revision: 883652
- rebuild for new boost 1.59.0

* Thu Sep 03 2015 cjw <cjw> 1.0.13-3.mga6
+ Revision: 872612
- rebuild with gcc 5

* Fri Jul 31 2015 daviddavid <daviddavid> 1.0.13-2.mga6
+ Revision: 859859
- rebuild for new boost-1.58.0

* Tue Mar 17 2015 akien <akien> 1.0.13-1.mga5
+ Revision: 818724
- Add missing BR on mesagl
- Version 1.0.13
- Factorise the bear engine libraries via the external bear-engine package
  o Build the game against the same version of the engine, but do not package
    the runtime libs provided by bear-engine (also used by plee-the-bear)
  o Install the game-specific library to the common %%_libdir/bear path
  o Drop RPATH since bear-engine uses a proper conf file in /etc/ld.so.conf.d/
  o This new packaging prevents conflicts with andy-super-great-park, though
    preventing the build of the bear libraries in each game will have to be
    worked upon with upstream
- Drop bear-factory subpackage, it is now provided by the bear package
- Install binary and data to the games-specific directories
- Fix license
- Move distribution stuff to main package (desktop file, icons)

* Wed Oct 15 2014 umeabot <umeabot> 1.0.8-4.mga5
+ Revision: 744322
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0.8-3.mga5
+ Revision: 677759
- Mageia 5 Mass Rebuild

* Sun Feb 09 2014 barjac <barjac> 1.0.8-2.mga5
+ Revision: 587591
- wxgtk needs to be 2.8
- revert to parallel build
- try non-parallel build
- missing BR freetype2-devel
- rebuild against boost-1.55

* Tue Dec 10 2013 juancho <juancho> 1.0.8-1.mga4
+ Revision: 556084
- imported package andy-super-great-park


* Sat Aug 24 2013 dap.darkness@gmail.com
- Initial build.
